tprintln

Macro tprintln 

macro_rules! tprintln {
    () => { ... };
    ($($arg:tt)*) => { ... };
}
Like println! but prefixes every line with the elapsed time since the program started (e.g. [ 1.234s]), producing a scrolling log that the user can review as history.